AuthResp class

AuthResp

Constructors

AuthResp({String? accessToken, int? expiresTime, String? tokenType, String? scope, String? refreshToken, String? tokenTime})
Constructor

Properties

accessToken ↔ String?
Access token
getter/setter pair
expiresTime ↔ int?
token expire time
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
refreshToken ↔ String?
refresh token
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope ↔ String?
token scope
getter/setter pair
tokenTime ↔ String?
token received time
getter/setter pair
tokenType ↔ String?
token type
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
to json map
toRawJson() → String
to json string
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → dynamic
from json map
fromRawJson(String? rawData) → dynamic
from json string